All Classes and Interfaces

Class
Description
A SyncListener with empty implementations of all interface methods.
A Box to put and get Objects of a specific Entity class.
An ObjectBox database that provides Boxes to put and get objects of specific entity classes (see BoxStore.boxFor(Class)).
Configures and builds a BoxStore with reasonable defaults.
A branch within a Tree.
You can throw this inside a QueryConsumer to signal Query.forEach(QueryConsumer) should "break".
Special bit flags used in cluster mode only.
Used by SyncClient to observe connectivity changes.
Base class for exceptions thrown when a constraint would be violated during a put operation.
Observer that can be subscribed to publishers (e.g.
 
The result of subscribing an @DataObserver using @SubscriptionBuilder.observer(DataObserver).
Tracks any number of DataSubscription objects, which can be canceled with a single DataSubscriptionList.cancel() call.
Transforms or processes data before it is given to subscribed DataObservers.
This exception occurs while working with a ToMany or ToOne of an object and the object is not attached to a Box (technically a BoxStore).
General exception for things that may go wrong with the database.
Listener for exceptions occurring during database operations.
Thrown when applying a database operation would exceed the (default) maxSizeInKByte configured for the Store.
Thrown when applying a transaction would exceed the maxDataSizeInKByte configured for the store.
Thrown when the maximum of readers (read transactions) was exceeded.
Thrown when there is an error with the data schema (data model).
Thrown when an error occurred that requires the store to be closed.
Debug flags typically enable additional "debug logging" that can be helpful to better understand what is going on internally.
 
 
Exceptions thrown in DataObserver and @DataTransformer can be observed by an error observer set via SubscriptionBuilder.onError(ErrorObserver).
Generic Factory that provides a resource on demand (if and when it is required).
Thrown when a special feature was used, which is not part of the native library.
Errors were detected in a database file, e.g.
Options to open a store with.
 
Converts between Object properties and byte arrays using FlexBuffers.
Wraps the ID of a matching object and a score when using Query.findIdsWithScores(long, long).
A FlexObjectConverter that uses Integer as map keys.
Like IntegerFlexMapConverter, but always restores integer map values as Long.
A thread-safe, unmodifiable List that gets Objects from their Box not until they are accessed.
A data leaf represents a data value in a Tree as a child of a Branch.
(Potentially internal) value object created in our JNI layer to represent a leaf with all stored data.
 
 
 
A FlexObjectConverter that uses Long as map keys.
Like LongFlexMapConverter, but always restores integer map values as Long.
Thrown if Query.findUnique() or Query.findUniqueId() is called, but the query matches more than one object.
Used as a converter if a property is annotated with @DefaultValue("").
Thrown if a property query aggregate function can not compute a result due to a number type overflowing.
 
Wraps a matching object and a score when using Query.findWithScores(long, long).
Not really an enum, but binary flags to use across languages
Errors related to pages were detected in a database file, e.g.
Provides access to platform-specific features.
Meta data describing a Property of an ObjectBox Entity.
Query for a specific property; create using Query.property(Property).
A condition on a Property, which can have an alias to allow referring to it later.
Property based query conditions with implementations split by number and type of values, such as LongCondition, LongLongCondition, LongArrayCondition and the general NullCondition.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Conditions for properties with an HnswIndex.
 
 
 
 
 
 
 
 
 
 
 
 
A repeatable Query returning the latest matching objects.
Builds a Query using conditions which can then be used to return a list of matching Objects.
 
Allows building queries with a fluent interface.
 
Decides which entities to keep as a query result.
A ThreadLocal that, given an original Query object, returns a copy, for each thread.
 
Meta info describing a relation including source and target entity.
 
 
Like StringFlexMapConverter, but always restores integer map values as Long.
Converts a String map entity property to a byte array database value using FlexBuffers.
ObjectBox Sync makes data available on other devices.
A builder to create a SyncClient; the builder itself should be created via Sync.client(BoxStore, String, SyncCredentials).
 
A collection of changes made to one entity type during a sync transaction.
Notifies of fine granular changes on the object level happening during sync.
ObjectBox sync client.
Internal sync client implementation.
 
Listens to sync completed events.
Listens to sync connection events.
Use the static helper methods to build Sync credentials, for example SyncCredentials.sharedSecret("secret").
 
Internal credentials implementation.
Internal credentials implementation for user and password authentication.
Flags to adjust sync behavior like additional logging.
Combines the functionality of a Sync client and a Sync server.
Builder for a Sync client and server hybrid setup, a SyncHybrid.
This listener has callback methods invoked by all fundamental synchronization events.
Listens to login events.
ObjectBox sync server.
Creates a SyncServer and allows to set additional configuration.
Bit flags to configure the Sync Server.
Internal sync server implementation.
 
A to-many relation of an entity that references multiple objects of a ToMany entity.
A to-one relation of an entity that references one object of a ToOne entity.
A higher level tree API operating on branch and leaf nodes.
Options flags for trees.
Thrown when a @Unique constraint would be violated during a put operation.
Defines if and how the database is checked for valid key/value (KV) entries when opening it.
Defines if and how the database is checked for structural consistency (pages) when opening it.