Class WalOptions

java.lang.Object
io.objectbox.flatbuffers.Table
io.objectbox.config.WalOptions

public final class WalOptions extends io.objectbox.flatbuffers.Table
Options to enable and configure WAL.
  • Nested Class Summary

    Nested Classes
    Modifier and Type
    Class
    Description
    static final class 
     
  • Field Summary

    Fields inherited from class io.objectbox.flatbuffers.Table

    bb, bb_pos
  • Constructor Summary

    Constructors
    Constructor
    Description
     
  • Method Summary

    Modifier and Type
    Method
    Description
    __assign(int _i, ByteBuffer _bb)
     
    void
    __init(int _i, ByteBuffer _bb)
     
    static void
    addMaxWalFileSizeInKbyte(io.objectbox.flatbuffers.FlatBufferBuilder builder, long maxWalFileSizeInKbyte)
     
    static void
    addMaxWalFileSizeOnOpenInKbyte(io.objectbox.flatbuffers.FlatBufferBuilder builder, long maxWalFileSizeOnOpenInKbyte)
     
    static void
    addWalFlags(io.objectbox.flatbuffers.FlatBufferBuilder builder, long walFlags)
     
    static int
    createWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder, long walFlags, long maxWalFileSizeOnOpenInKbyte, long maxWalFileSizeInKbyte)
     
    static int
    endWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder)
     
    static WalOptions
     
    static WalOptions
     
    long
    The WAL file gets consolidated when it reaches this size limit after a commit.
    long
    The WAL file gets consolidated when it reached this size limit when opening the database.
    static void
    startWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder)
     
    static void
     
    long
    Flags to enable and change default WAL behavior, e.g.

    Methods inherited from class io.objectbox.flatbuffers.Table

    __has_identifier, __indirect, __indirect, __offset, __offset, __reset, __reset, __string, __string, __union, __union, __vector, __vector_as_bytebuffer, __vector_in_bytebuffer, __vector_len, compareStrings, compareStrings, getByteBuffer, keysCompare, sortTables

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • WalOptions

      public WalOptions()
  • Method Details

    • ValidateVersion

      public static void ValidateVersion()
    • getRootAsWalOptions

      public static WalOptions getRootAsWalOptions(ByteBuffer _bb)
    • getRootAsWalOptions

      public static WalOptions getRootAsWalOptions(ByteBuffer _bb, WalOptions obj)
    • __init

      public void __init(int _i, ByteBuffer _bb)
    • __assign

      public WalOptions __assign(int _i, ByteBuffer _bb)
    • walFlags

      public long walFlags()
      Flags to enable and change default WAL behavior, e.g. no sync to disk option.
    • maxWalFileSizeOnOpenInKbyte

      public long maxWalFileSizeOnOpenInKbyte()
      The WAL file gets consolidated when it reached this size limit when opening the database. This setting is meant for applications that prefer to consolidate on startup, which may avoid consolidations on commits while the application is running. The default is 4096 (4 MB).
    • maxWalFileSizeInKbyte

      public long maxWalFileSizeInKbyte()
      The WAL file gets consolidated when it reaches this size limit after a commit. As consolidation takes some time, it is a trade-off between accumulating enough data and the time the consolidation takes (longer with more data). The default is 16384 (16 MB).
    • createWalOptions

      public static int createWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder, long walFlags, long maxWalFileSizeOnOpenInKbyte, long maxWalFileSizeInKbyte)
    • startWalOptions

      public static void startWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder)
    • addWalFlags

      public static void addWalFlags(io.objectbox.flatbuffers.FlatBufferBuilder builder, long walFlags)
    • addMaxWalFileSizeOnOpenInKbyte

      public static void addMaxWalFileSizeOnOpenInKbyte(io.objectbox.flatbuffers.FlatBufferBuilder builder, long maxWalFileSizeOnOpenInKbyte)
    • addMaxWalFileSizeInKbyte

      public static void addMaxWalFileSizeInKbyte(io.objectbox.flatbuffers.FlatBufferBuilder builder, long maxWalFileSizeInKbyte)
    • endWalOptions

      public static int endWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder)