Package io.objectbox.relation
@ParametersAreNonnullByDefault
package io.objectbox.relation
Classes to manage
ToOne and ToMany
relations between Entities.
For more details look at the documentation of individual classes and docs.objectbox.io/relations.
-
ClassDescriptionRelationInfo<SOURCE,
TARGET> Meta info describing a relation including source and target entity.ToMany<TARGET>A List representing a to-many relation.ToOne<TARGET>Manages a to-one relation: resolves the target object, keeps the target Id in sync, etc.