Class SyncCredentialsToken

java.lang.Object
io.objectbox.sync.SyncCredentials
io.objectbox.sync.SyncCredentialsToken

@Internal public class SyncCredentialsToken extends SyncCredentials
Internal credentials implementation. Use SyncCredentials to build credentials.
  • Method Details

    • getTypeId

      public long getTypeId()
    • getTokenBytes

      @Nullable public byte[] getTokenBytes()
    • clear

      public void clear()
      Clear after usage.

      Note that actual data is not removed from memory until the next garbage collector run. Anyhow, the credentials are still kept in memory by the native component.