Interface SyncServer

All Superinterfaces:
AutoCloseable, Closeable
All Known Implementing Classes:
SyncServerImpl

@Experimental public interface SyncServer extends Closeable
  • Method Details

    • getUrl

      String getUrl()
      Gets the URL the server is running at.
    • getPort

      int getPort()
      Gets the port the server has bound to.
    • isRunning

      boolean isRunning()
      Returns if the server is up and running.
    • getStatsString

      String getStatsString()
      Gets some statistics from the sync server.
    • setSyncChangeListener

      void setSyncChangeListener(@Nullable SyncChangeListener listener)
      Sets a SyncChangeListener. Replaces a previously set listener. Set to null to remove the listener.
    • start

      void start()
      Starts the server (e.g. bind to port) and gets everything operational.
    • stop

      void stop()
      Stops the server.
    • close

      void close()
      Closes and cleans up all resources used by this sync server. It can no longer be used afterwards, build a new sync server instead. Does nothing if this sync server has already been closed.
      Specified by:
      close in interface AutoCloseable
      Specified by:
      close in interface Closeable