Package io.objectbox.sync.server
Class SyncServerBuilder
java.lang.Object
io.objectbox.sync.server.SyncServerBuilder
Creates a
SyncServer and allows to set additional configuration.-
Constructor Summary
ConstructorsConstructorDescriptionSyncServerBuilder(BoxStore boxStore, String url, SyncCredentials authenticatorCredentials) -
Method Summary
Modifier and TypeMethodDescriptionauthenticatorCredentials(SyncCredentials authenticatorCredentials) Adds additional authenticator credentials to authenticate clients with.build()Builds and returns a Sync server ready toSyncServer.start().Builds,startsand returns a Sync server.certificatePath(String certificatePath) changeListener(SyncChangeListener changeListener) Sets a listener to observe fine granular changes happening during sync.Adds a server peer, to which this server should connect to as a client usingSyncCredentials.none().peer(String url, SyncCredentials credentials) Adds a server peer, to which this server should connect to as a client using the given credentials.
-
Constructor Details
-
SyncServerBuilder
-
-
Method Details
-
certificatePath
-
authenticatorCredentials
Adds additional authenticator credentials to authenticate clients with. -
changeListener
Sets a listener to observe fine granular changes happening during sync.This listener can also be
set or removedon the Sync server directly. -
peer
Adds a server peer, to which this server should connect to as a client usingSyncCredentials.none(). -
peer
Adds a server peer, to which this server should connect to as a client using the given credentials. -
build
Builds and returns a Sync server ready toSyncServer.start().Note: this clears all previously set authenticator credentials.
-
buildAndStart
Builds,startsand returns a Sync server.
-