Package io.objectbox.config
Class WalOptions
java.lang.Object
io.objectbox.flatbuffers.Table
io.objectbox.config.WalOptions
public final class WalOptions
extends io.objectbox.flatbuffers.Table
Options to enable and configure WAL.
-
Nested Class Summary
Nested Classes -
Field Summary
Fields inherited from class io.objectbox.flatbuffers.Table
bb, bb_pos -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription__assign(int _i, ByteBuffer _bb) void__init(int _i, ByteBuffer _bb) static voidaddMaxWalFileSizeInKbyte(io.objectbox.flatbuffers.FlatBufferBuilder builder, long maxWalFileSizeInKbyte) static voidaddMaxWalFileSizeOnOpenInKbyte(io.objectbox.flatbuffers.FlatBufferBuilder builder, long maxWalFileSizeOnOpenInKbyte) static voidaddWalFlags(io.objectbox.flatbuffers.FlatBufferBuilder builder, long walFlags) static intcreateWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder, long walFlags, long maxWalFileSizeOnOpenInKbyte, long maxWalFileSizeInKbyte) static intendWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder) static WalOptionsstatic WalOptionsgetRootAsWalOptions(ByteBuffer _bb, WalOptions obj) longThe WAL file gets consolidated when it reaches this size limit after a commit.longThe WAL file gets consolidated when it reached this size limit when opening the database.static voidstartWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder) static voidlongwalFlags()Flags to enable and change default WAL behavior, e.g.Methods inherited from class io.objectbox.flatbuffers.Table
__has_identifier, __indirect, __indirect, __offset, __offset, __reset, __reset, __string, __string, __union, __union, __vector, __vector_as_bytebuffer, __vector_in_bytebuffer, __vector_len, compareStrings, compareStrings, getByteBuffer, keysCompare, sortTables
-
Constructor Details
-
WalOptions
public WalOptions()
-
-
Method Details
-
ValidateVersion
public static void ValidateVersion() -
getRootAsWalOptions
-
getRootAsWalOptions
-
__init
-
__assign
-
walFlags
public long walFlags()Flags to enable and change default WAL behavior, e.g. no sync to disk option. -
maxWalFileSizeOnOpenInKbyte
public long maxWalFileSizeOnOpenInKbyte()The WAL file gets consolidated when it reached this size limit when opening the database. This setting is meant for applications that prefer to consolidate on startup, which may avoid consolidations on commits while the application is running. The default is 4096 (4 MB). -
maxWalFileSizeInKbyte
public long maxWalFileSizeInKbyte()The WAL file gets consolidated when it reaches this size limit after a commit. As consolidation takes some time, it is a trade-off between accumulating enough data and the time the consolidation takes (longer with more data). The default is 16384 (16 MB). -
createWalOptions
public static int createWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder, long walFlags, long maxWalFileSizeOnOpenInKbyte, long maxWalFileSizeInKbyte) -
startWalOptions
public static void startWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder) -
addWalFlags
public static void addWalFlags(io.objectbox.flatbuffers.FlatBufferBuilder builder, long walFlags) -
addMaxWalFileSizeOnOpenInKbyte
public static void addMaxWalFileSizeOnOpenInKbyte(io.objectbox.flatbuffers.FlatBufferBuilder builder, long maxWalFileSizeOnOpenInKbyte) -
addMaxWalFileSizeInKbyte
public static void addMaxWalFileSizeInKbyte(io.objectbox.flatbuffers.FlatBufferBuilder builder, long maxWalFileSizeInKbyte) -
endWalOptions
public static int endWalOptions(io.objectbox.flatbuffers.FlatBufferBuilder builder)
-