Package io.objectbox.sync
Class SyncCredentialsToken
java.lang.Object
io.objectbox.sync.SyncCredentials
io.objectbox.sync.SyncCredentialsToken
Internal credentials implementation. Use
SyncCredentials to build credentials.-
Nested Class Summary
Nested classes/interfaces inherited from class io.objectbox.sync.SyncCredentials
SyncCredentials.CredentialsType -
Method Summary
Methods inherited from class io.objectbox.sync.SyncCredentials
google, none, sharedSecret, sharedSecret
-
Method Details
-
getTypeId
public long getTypeId() -
getTokenBytes
@Nullable public byte[] getTokenBytes() -
clear
public void clear()Clear after usage.Note that actual data is not removed from memory until the next garbage collector run. Anyhow, the credentials are still kept in memory by the native component.
-